@@ -10,9 +10,6 @@ from yopypi import logging, config_defaults
 CWD = path.abspath(__file__)
 APP_CWD = path.dirname(CWD)
 
-# local pid dir to avoid running as root
-PID_DIR = APP_CWD+'/pid'
-
 # Initialize config
 config = config_defaults()
 log = logging(module='server')
@@ -22,8 +19,8 @@ log = logging(module='server')
 def index(uri):
     up = running()
     if up:
+        log.write("pypi is up, redirecting to http://pypi.python.org/%s" % uri)
         redirect('http://pypi.python.org/%s' % uri)
-        log.write("pypi is up, redirecting to %s" % uri)
     else:
          log.write("pypi seems to be down, trying mirrors")
          for mirror in config['mirrors']:
@@ -36,9 +33,9 @@ def index(uri):
 
 def main():
     try:
+        log.write("running yopypi server...")
         debug(True)
         run(host=config['web_host'], port=config['web_port'], quiet=True)
-        log.write("running yopypi server...")
     except Exception, e:
         log.write("Couldn't start the yopypi server:%s" % e)
 
